@@ -21,6 +21,10 @@ public class NumberValue extends PlainText implements AttributeValuable, CSSValu
 	 * 無限回を表すNumber。
 	 */
 	public static final Number INFINITE = new Infinite();
+	/**
+	 * アスタリスク(残り全て)を表すNumber。
+	 */
+	public static final Number LEFTOVER = new Leftover();
 
 	/**
 	 * 符号。
@@ -288,6 +292,11 @@ public class NumberValue extends PlainText implements AttributeValuable, CSSValu
 			super.setText( INFINITE.toString() );
 			return;
 		}
+		if ( LEFTOVER.toString().equalsIgnoreCase( str ) ) {
+			setNumber( Sign.NON, LEFTOVER );
+			super.setText( LEFTOVER.toString() );
+			return;
+		}
 
 		int	start = 1;
 		char	ch = str.charAt( 0 );
