@@ -1566,5 +1566,19 @@ public abstract class Page implements Serializable {
 			parts[i].set();
 		}
 	}
+
+	/**
+	 * セッションID付きURLへの置換。<br>
+	 * これが true を返すと、ブラウザのクッキー対応・非対応に応じてURLを書き換え
+	 * クッキー非対応ブラウザでは URL 置換が行われます。<br>
+	 * これが false を返すと、クッキー対応・非対応に関わらずURL書き換えを
+	 * 行いません。
+	 * ただし、アクセス元が携帯であるとこの戻り値を無視して URL 置換を行います。
+	 * @return 常に false を返します。
+	 * 必要に応じてオーバーライドして下さい。
+	 */
+	public boolean isEncodeURL() {
+		return false;
+	}
 }
 
