@@ -101,7 +101,7 @@ public class Linker extends paraselene.mockup.output.Readme implements OutputNo
 	private PrePage crt_page = null;
 
 	public static boolean flag = false;
-	public static Linker	readme = new Linker();
+	public static final Linker	readme = new Linker();
 
 	Linker() {
 		super();
