@@ -38,7 +38,7 @@ public abstract class Output {
 		return buf.toString();
 	}
 
-	static void mkdir( String dir ) {
+	public static void mkdir( String dir ) {
 		if ( dir == null )	return;
 		if ( new File( dir ).exists() )	return;
 		String[]	path = dir.split( "[/\\\\]+" );
