@@ -17,46 +17,6 @@ import paraselene.dyna.*;
 import paraselene.dyna.mockup.*;
 
 
-enum LineSeparator {
-	CR( "cr", "\r" ),
-	LF( "lf", "\n" ),
-	CRLF( "crlf", "\r\n" ),
-	LFCR( "lfcr", "\n\r" );
-
-	private static LineSeparator	use;
-	private String name;
-	private String code;
-	private LineSeparator( String n, String c ) {
-		name = n;
-		code = c;
-	}
-	static String getOSName() {
-		LineSeparator[]	ls = values();
-		for ( int i = 0; i < ls.length; i++ ) {
-			if ( ls[i].code.equals( System.getProperty("line.separator") ) ) {
-				return ls[i].name;
-			}
-		}
-		return CRLF.name;
-	}
-
-	static boolean setUse( String name ) {
-		LineSeparator[]	ls = values();
-		for ( int i = 0; i < ls.length; i++ ) {
-			if ( ls[i].name.equals( name ) ) {
-				use = ls[i];
-				return true;
-			}
-		}
-		return false;
-	}
-
-	static String getUse() {
-		if ( use == null )	return System.getProperty("line.separator");
-		return use.code;
-	}
-}
-
 class HtmlExt {
 	private static String[]	ext = new String[] {
 		"htm", "html", "xht", "xhtml"
