@@ -176,7 +176,7 @@ public class PrePage extends DynamicPage implements OutputNo {
 		case 2:
 			return package_name;
 		case 3:
-			return path;
+			return Output.toHtmlPath( path );
 		case 4:
 			return class_name;
 
