@@ -29,8 +29,8 @@ class TableSource extends TagSource {
 	private String	table_name = null;
 	private String	enum_name = null;
 
-	TableSource() {
-		super( "table", false );
+	TableSource( String html ) {
+		super( html, "table", false );
 	}
 
 	private void build( ArrayList<TableEnum> list ) {
