@@ -130,8 +130,8 @@ public class TagMap {
 	public static Tag makeTag( String n, ArrayList<Attribute> attr, String enc, URIResolver ur, GrantTagProvider[] ex ) throws Exception {
 		GrantTag	gt = null;
 		Tag	t = new Tag( n, DynamicPage.isSimpleTag( n ) );
+		t.setAttribute( attr.toArray( new Attribute[0] ) );
 		if ( ex != null ) {
-			Attribute[]	a = attr.toArray( new Attribute[0] );
 			for ( int i = 0; i < ex.length; i++ ) {
 				gt = ex[i].getGrantTag( t );
 				if ( gt != null )	break;
