@@ -66,13 +66,12 @@ class CacheBin implements CacheAjax {
 	private void flush( OutputStream out ) throws IOException {
 		if ( out instanceof GZIPOutputStream ) {
 			((GZIPOutputStream)out).finish();
-			return;
 		}
 		out.flush();
 	}
 
 	private void write_once( RequestParameter param, SessionData data, HttpServletResponse res ) throws IOException {
-		res.setContentLength( size );
+		if ( !gzip )	res.setContentLength( size );
 		OutputStream	out = getOutpuStream( res );
 		out.write( buf, 0, size );
 		flush( out );
