@@ -141,6 +141,7 @@ public class History implements Serializable {
 	 */
 	public void add( Page page ) {
 		if ( page == null )	return;
+		page = page.getParentPage();
 		if ( addPopup( page ) )	return;
 		synchronized( hist ) {
 			int	cnt = getHistoryCount();
@@ -274,7 +275,11 @@ public class History implements Serializable {
 			int	cnt = getHistoryCount();
 			for ( int i = 0; i < cnt; i++ ) {
 				page = hist.get( i );
-				if ( page.getUniqueKey().equals( uni ) )	return page;
+				Page	hit = page.getBypassPage( uni );
+				if ( hit != null ) {
+					initSatellitePage( page );
+					return hit;
+				}
 			}
 		}
 		return null;
