@@ -55,7 +55,8 @@ class ChildKiller extends Thread {
 	private static ChildKiller	killer = new ChildKiller();
 
 	private ChildKiller(){}
-	static void start( ArrayList<Child> list ) {
+
+	static void init( ArrayList<Child> list ) {
 		synchronized( killer ) {
 			if ( running != null )	return;
 			running = list;
