@@ -13,7 +13,8 @@ import javax.servlet.http.*;
 import paraselene.*;
 import paraselene.ajax.*;
 
-class DebugEcho implements HttpSessionBindingListener {
+class DebugEcho implements HttpSessionBindingListener, Serializable {
+	private static final long serialVersionUID = 2L;
 	private static final String	SESSION_KEY = "paraselene$DebugEcho$";
 	private String	key;
 	private String	session_id;
@@ -95,6 +96,7 @@ public class Option implements Serializable {
 		stack = list.toArray( new String[0] );
 	}
 
+	private static final long serialVersionUID = 2L;
 	private static final String MYSELF = "paraselene.supervisor.Option";
 	private static volatile boolean debug_f = false;
 	private static ArrayList<PageFactory>	factory =
