@@ -85,7 +85,7 @@ public abstract class PageFactory extends Thread {
 		}
 	}
 
-	protected boolean	teapot_f = false;
+	protected volatile boolean	teapot_f = false;
 
 	int	page_cnt;
 	int include_cnt;
@@ -281,10 +281,6 @@ public abstract class PageFactory extends Thread {
 					if ( !name.equals( path[i].substring( 0, name.length() ) ) ) continue;
 				}
 				hit = name;
-				if ( j != 0 && list_cnt > 1 ) {
-					alias_list.set( j, alias_list.set( j - 1, name ) );
-					full_match.set( j, full_match.set( j - 1, full ) );
-				}
 			}
 			if ( hit == null )	continue;
 			Integer	id = alias.get( hit );
