@@ -330,12 +330,23 @@ public class RequestParameter implements Serializable {
 		header.put( name.toLowerCase( Locale.ENGLISH ), val );
 	}
 
+	static final String X_FORWARD = "X-Forwarded-For";
+
+	private String getRemoteAddr( HttpServletRequest req ) {
+		String	x = req.getHeader( X_FORWARD );
+		if ( x != null )  {
+			String[]	tmp = x.split( "[\\.:]" );
+			if ( tmp.length >= 4 )	return x;
+		}
+		return req.getRemoteAddr();
+	}
+
 	void setParam( Method m, HttpServletRequest request, Supervisor sv ) {
 		setSupervisor( sv );
 		setMethod( m );
 		setSession( request.getSession( false ) );
 		setCookie( request.getCookies() );
-		setRemoteAddr( request.getRemoteAddr() );
+		setRemoteAddr( getRemoteAddr( request ) );
 		try {
 			StringBuffer	buf = request.getRequestURL();
 			String	query = request.getQueryString();
