@@ -458,7 +458,8 @@ public class SandBox extends Thread {
 		int include_cnt = low_cnt >> 2;
 		long	max_interval = 1000 * 15;
 		long	interval = 500;
-		long	last_tm = new Date().getTime();
+//		long	last_tm = new Date().getTime();
+		long	last_tm = 0;
 
 		while( true ) {
 			if ( waiting == null || running == null )	return;
