@@ -257,10 +257,10 @@ public abstract class Supervisor extends HttpServlet {
 				buf = buf.append( part[i] );
 			}
 			uri = buf.toString();
+			uri = URIValue.encode( uri, enc, xml_f );
 			if ( holder instanceof DataHolder ) {
-				uri = ((DataHolder)holder).response.encodeURL( URIValue.encode( uri, enc, xml_f ) );
+				uri = ((DataHolder)holder).encodeURL( uri, page );
 			}
-			else	uri = URIValue.encode( uri, enc, xml_f );
 		}
 		else {
 			alias_f = holder.getPageFactory().isAlias( uri );
@@ -287,11 +287,9 @@ public abstract class Supervisor extends HttpServlet {
 					uri = p.toString();
 				}
 			}
+			uri = URIValue.encode( uri, enc, xml_f );
 			if ( !alias_f && isMyHost( uri ) && holder instanceof DataHolder ) {
-				uri = ((DataHolder)holder).response.encodeURL( URIValue.encode( uri, enc, xml_f ) );
-			}
-			else {
-				uri = URIValue.encode( uri, enc, xml_f );
+				uri = ((DataHolder)holder).encodeURL( uri, page );
 			}
 		}
 		if ( head != null ) {
@@ -1043,7 +1041,7 @@ public abstract class Supervisor extends HttpServlet {
 			}
 			doAction( req, res );
 		}
-		catch( Exception e ) {
+		catch( Throwable e ) {
 			onErrorDebug( e, req, res );
 		}
 		finally {
@@ -1063,7 +1061,7 @@ public abstract class Supervisor extends HttpServlet {
 			}
 			doAction( req, res );
 		}
-		catch( Exception e ) {
+		catch( Throwable e ) {
 			onErrorDebug( e, req, res );
 		}
 		finally {
